### Name: npscoef
### Title: Smooth Coefficient Kernel Regression
### Aliases: npscoef npscoef.call npscoef.default npscoef.formula
###   npscoef.scbandwidth
### Keywords: nonparametric

### ** Examples

# EXAMPLE 1 (INTERFACE=FORMULA): Typically, the variables z will be
# equal to the regressors x, as in the following example.

set.seed(12345)

n <- 250
x <- sort(runif(n,min=-2*pi,max=2*pi))
y <- sin(x) + rnorm(n,sd = 0.2)

bw <- npscoefbw(formula=y~x)

model <- npscoef(bw)

# We could manually plot fitted values and error bounds as follows:

plot(x,y)
lines(x,predict(model))
lines(x,predict(model)-2*se(model),lty=2,col="red")
lines(x,predict(model)+2*se(model),lty=2,col="red")

## Not run: 
##D 
##D # EXAMPLE 1 (INTERFACE=DATA FRAME): Typically, the variables z will be
##D # equal to the regressors x, as in the following example.
##D 
##D set.seed(12345)
##D 
##D n <- 250
##D x <- sort(runif(n,min=-2*pi,max=2*pi))
##D y <- sin(x) + rnorm(n,sd = 0.2)
##D 
##D bw <- npscoefbw(xdat=x, ydat=y)
##D 
##D model <- npscoef(bw)
##D 
##D # We could manually plot fitted values and error bounds as follows:
##D 
##D plot(x,y)
##D lines(x,predict(model))
##D lines(x,predict(model)-2*se(model),lty=2,col="red")
##D lines(x,predict(model)+2*se(model),lty=2,col="red")
##D 
##D # EXAMPLE 2 (INTERFACE=FORMULA): We can handle z and x being different
##D # (this would be useful in, say, a time series context where z might be
##D # time yielding a time-varying smooth coefficient model).
##D 
##D n <- 250
##D x <- runif(n)
##D z <- runif(n, min=-2, max=2)
##D y <- x*exp(z)*(1.0+rnorm(n,sd = 0.2))
##D bw <- npscoefbw(y~x|z)
##D model <- npscoef(bw)
##D plot(model)
##D 
##D # EXAMPLE 2 (INTERFACE=DATA FRAME): We can handle z and x being different
##D # (this would be useful in, say, a time series context where z might be
##D # time yielding a time-varying smooth coefficient model)
##D 
##D n <- 250
##D x <- runif(n)
##D z <- runif(n, min=-2, max=2)
##D y <- x*exp(z)*(1.0+rnorm(n,sd = 0.2))
##D bw <- npscoefbw(xdat=x, ydat=y, zdat=z)
##D model <- npscoef(bw)
##D plot(model)
## End(Not run) 



